@@ -10,7 +10,7 @@ use std::cell::RefCell;
 
 use adw::prelude::*;
 use adw::subclass::prelude::*;
-use gtk::glib::subclass::*;
+use gtk::glib::subclass::InitializingObject;
 use gtk::glib::Properties;
 use gtk::{gio, glib, CompositeTemplate, TemplateChild};
 
@@ -22,6 +22,7 @@ use gtk::{gio, glib, CompositeTemplate, TemplateChild};
 const LOG_DOMAIN: &str = "xdpp-app-chooser-row";
 
 mod imp {
+    #[allow(clippy::wildcard_imports)]
     use super::*;
 
     #[derive(CompositeTemplate, Default, Properties)]
@@ -78,9 +79,7 @@ mod imp {
             let name = info.display_name();
             self.obj().set_title(&name);
 
-            let icon = info.icon();
-            if icon.is_some() {
-                let icon = icon.unwrap();
+            if let Some(icon) = info.icon() {
                 self.image.set_from_gicon(&icon);
             }
 
@@ -101,6 +100,12 @@ impl AppChooserRow {
     }
 }
 
+impl Default for AppChooserRow {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl AppChooserRow {
     pub fn from_app_id(app_id: &str) -> Self {
         glib::Object::builder().property("app-id", app_id).build()
