@@ -109,7 +109,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct GridItem(ObjectSubclass<imp::GridItem>)
-        @extends adw::Bin, gtk::Widget;
+        @extends adw::Bin, gtk::Widget,
+        @implements gtk::Accessible, gtk::Buildable, gtk::ConstraintTarget;
 }
 
 impl Default for GridItem {
@@ -123,4 +124,12 @@ impl GridItem {
     pub fn new() -> Self {
         Self::default()
     }
+
+    pub fn set_thumbnail(&self, path: String) {
+        let imp = self.imp();
+
+        if *imp.thumbnail_mode.borrow() != ThumbnailMode::Never {
+            imp.icon.get().set_from_file(Some(path));
+        }
+    }
 }
